# Replication Code for Candelaria Garay, Brian Palmer-Rubin, and Mathias Poertner, "Organizational Brokerage of Social Benefits: Evidence from Mexico," World Development

#Analysis conducted in R version 3.6.0

#install the following packages
library(texreg)
library(ggplot2)
library(cowplot)
library(xtable)
library(list)
library(plyr)

setwd("~Replication_materialsWD")

load("repdatWD.RData")

data<-repdatWD

######### Creating Subsetted Datasets for Analysis

# Data Chiapas

data.chiapas<-data[data$estado=="Chiapas",]
dim(data.chiapas)

# Data DF

data.df<-data[data$estado=="DF",]
dim(data.df)

# Just control and Org treatment:

data.listOrg<-data[data$list.level!="campaign",]

data.listOrg<-data.listOrg[!is.na(data.listOrg$list.resp),]

dim(data.listOrg)

# Just control and Camp treatment:

data.listCamp<-data[data$list.level!="org",]

dim(data.listCamp)

# For each state
data.Camp.Ch<-data.listCamp[data.listCamp$estado=="Chiapas",]
dim(data.Camp.Ch)

data.Org.Ch<-data.listOrg[data.listOrg$estado=="Chiapas",]
dim(data.Org.Ch)

data.Camp.DF<-data.listCamp[data.listCamp$estado=="DF",]
dim(data.Camp.DF)

data.Org.DF<-data.listOrg[data.listOrg$estado=="DF",]
dim(data.Org.DF)


# For high and low income
lo.inc.Camp<-data.listCamp[data.listCamp$income2=="low",]
dim(lo.inc.Camp)

hi.inc.Camp<-data.listCamp[data.listCamp$income2=="high",]
dim(hi.inc.Camp)

lo.inc.Org<-data.listOrg[data.listOrg$income2=="low",]
dim(lo.inc.Org)

hi.inc.Org<-data.listOrg[data.listOrg$income2=="high",]
dim(hi.inc.Org)

# By state

lo.inc.Camp.Ch<-lo.inc.Camp[lo.inc.Camp$estado=="Chiapas",]

lo.inc.Camp.DF<-lo.inc.Camp[lo.inc.Camp$estado=="DF",]

hi.inc.Camp.Ch<-hi.inc.Camp[hi.inc.Camp$estado=="Chiapas",]

hi.inc.Camp.DF<-hi.inc.Camp[hi.inc.Camp$estado=="DF",]

lo.inc.Org.Ch<-lo.inc.Org[lo.inc.Org$estado=="Chiapas",]

lo.inc.Org.DF<-lo.inc.Org[lo.inc.Org$estado=="DF",]

hi.inc.Org.Ch<-hi.inc.Org[hi.inc.Org$estado=="Chiapas",]

hi.inc.Org.DF<-hi.inc.Org[hi.inc.Org$estado=="DF",]


# Org members and non

dat.orgmemb<-data[data$org_mem2==1,]

data.membOrg<-dat.orgmemb[dat.orgmemb$list.level!="campaign",]

data.membCamp<-dat.orgmemb[dat.orgmemb$list.level!="org",]

dat.nonmemb<-data[data$org_mem2==0,]

data.nonmembOrg<-dat.nonmemb[dat.nonmemb$list.level!="campaign",]

data.nonmembCamp<-dat.nonmemb[dat.nonmemb$list.level!="org",]


lo.inc.Camp.memb<-data.membCamp[data.membCamp$income2=="low",]

lo.inc.Camp.nonmemb<-data.nonmembCamp[data.membCamp$income2=="low",]

hi.inc.Camp.memb<-data.membCamp[data.membCamp$income2=="high",]

hi.inc.Camp.nonmemb<-data.nonmembCamp[data.nonmembCamp$income2=="high",]

lo.inc.Org.memb<-data.membOrg[data.membOrg$income2=="low",]

lo.inc.Org.nonmemb<-data.nonmembOrg[data.nonmembOrg$income2=="low",]

hi.inc.Org.memb<-data.membOrg[data.membOrg$income2=="high",]

hi.inc.Org.nonmemb<-data.nonmembOrg[data.nonmembOrg$income2=="high",]


# By Beneficiary Status

data.BenProsperaOrg<-data.listOrg[data.listOrg$ben.prospera==1&!is.na(data.listOrg$ben.prospera),]

dim(data.BenProsperaOrg)

data.BenProsperaCamp<-data.listCamp[data.listCamp$ben.prospera==1&!is.na(data.listCamp$ben.prospera),]

dim(data.BenProsperaCamp)


data.BenNonProsperaOrg<-data.listOrg[data.listOrg$ben.non.prospera==1&!is.na(data.listOrg$ben.non.prospera),]

dim(data.BenNonProsperaOrg)

data.BenNonProsperaCamp<-data.listCamp[data.listCamp$ben.non.prospera==1&!is.na(data.listCamp$ben.non.prospera),]

dim(data.BenNonProsperaCamp)


########## Table 2: Raw Values for List Experiment

table(data$list.level)

table(data$list.resp, data$list.level)

mean(data$list.resp[data$list.level=="control"],na.rm=T)
mean(data$list.resp[data$list.level=="campaign"],na.rm=T)
mean(data$list.resp[data$list.level=="org"],na.rm=T)


########## Table 3: Overall Treatment Effects

#### Campaign Treatment

camp.list <- ictreg(list.resp ~ 1, data = data.listCamp,
                    treat = "list.treat", J=3, method = "lm")

summary(camp.list)

camp.list[[1]]

# Repeat with NLS

camp.listNLS <- ictreg(list.resp ~ 1, data = data.listCamp,
                    treat = "list.treat", J=3, method = "nls")

summary(camp.listNLS)

camp.listNLS[[1]]

# Chiapas

camp.list.ch <- ictreg(list.resp ~ 1, data = data.Camp.Ch,
                       treat = "list.treat", J=3, method = "lm")

summary(camp.list.ch)

# DF

camp.list.df <- ictreg(list.resp ~ 1, data = data.Camp.DF,
                       treat = "list.treat", J=3, method = "lm")

summary(camp.list.df)

# Difference

camp.list.diff <- ictreg(list.resp ~ estado, data = data.listCamp,
                      treat = "list.treat", J=3, method = "lm")

summary(camp.list.diff)


# Repeat with NLS

camp.list.diffNLS <- ictreg(list.resp ~ estado, data = data.listCamp,
                         treat = "list.treat", J=3, method = "nls")

summary(camp.list.diffNLS)

#### Org. treatment

org.list <- ictreg(list.resp ~ 1, data = data.listOrg,
                   treat = "list.treat", J=3, method = "lm")

summary(org.list)

# Repeat with NLS

org.listNLS <- ictreg(list.resp ~ 1, data = data.listOrg,
                   treat = "list.treat", J=3, method = "nls")

summary(org.listNLS)

# Chiapas

org.list.ch <- ictreg(list.resp ~ 1, data = data.Org.Ch,
                      treat = "list.treat", J=3, method = "lm")

summary(org.list.ch)

# DF

org.list.df <- ictreg(list.resp ~ 1, data = data.Org.DF,
                      treat = "list.treat", J=3, method = "lm")

summary(org.list.df)

# Difference

org.list.ed <- ictreg(list.resp ~ estado, data = data.listOrg,
                      treat = "list.treat", J=3, method = "lm")

summary(org.list.ed)


# Repeat with NLS

org.list.edNLS <- ictreg(list.resp ~ estado, data = data.listOrg,
                      treat = "list.treat", J=3, method = "nls")

summary(org.list.edNLS)

########## Table 4: Differences in Treatment Effects by Beneficiary Status

### Campaign Treatment

camp.list.ben <- ictreg(list.resp ~ ben.dum, data = data.listCamp,
                       treat = "list.treat", J=3, method = "lm")

summary(camp.list.ben)

camp.list.pros<-ictreg(list.resp ~ ben.prospera, data = data.listCamp,
                      treat = "list.treat", J=3, method = "lm")

summary(camp.list.pros)

camp.list.non<-ictreg(list.resp ~ ben.non.prospera, data = data.listCamp,
                     treat = "list.treat", J=3, method = "lm")

summary(camp.list.non)

camp.list.disc<-ictreg(list.resp ~ ben.disc, data = data.listCamp,
                      treat = "list.treat", J=3, method = "lm")

summary(camp.list.disc)

### Org. Treatment

org.list.ben <- ictreg(list.resp ~ ben.dum, data = data.listOrg,
                       treat = "list.treat", J=3, method = "lm")

summary(org.list.ben)

org.list.pros<-ictreg(list.resp ~ ben.prospera, data = data.listOrg,
                     treat = "list.treat", J=3, method = "lm")

summary(org.list.pros)

org.list.non<-ictreg(list.resp ~ ben.non.prospera, data = data.listOrg,
                      treat = "list.treat", J=3, method = "lm")

summary(org.list.non)

org.list.disc<-ictreg(list.resp ~ ben.disc, data = data.listOrg,
                     treat = "list.treat", J=3, method = "lm")

summary(org.list.disc)

########## Repeat Table 4 Using NLS

### Campaign Treatment

camp.list.benNLS <- ictreg(list.resp ~ ben.dum, data = data.listCamp,
                        treat = "list.treat", J=3, method = "nls")

summary(camp.list.benNLS)

camp.list.prosNLS<-ictreg(list.resp ~ ben.prospera, data = data.listCamp,
                       treat = "list.treat", J=3, method = "nls")

summary(camp.list.prosNLS)

camp.list.nonNLS<-ictreg(list.resp ~ ben.non.prospera, data = data.listCamp,
                      treat = "list.treat", J=3, method = "nls")

summary(camp.list.nonNLS)

### Org. Treatment

org.list.benNLS <- ictreg(list.resp ~ ben.dum, data = data.listOrg,
                       treat = "list.treat", J=3, method = "nls")

summary(org.list.benNLS)

org.list.prosNLS<-ictreg(list.resp ~ ben.prospera, data = data.listOrg,
                      treat = "list.treat", J=3, method = "nls")

summary(org.list.prosNLS)

org.list.nonNLS<-ictreg(list.resp ~ ben.non.prospera, data = data.listOrg,
                     treat = "list.treat", J=3, method = "nls")

summary(org.list.nonNLS)



########## Table 5: Comparing Low and High Income Respondents

### Campaign Treatment

camp.list.lo <- ictreg(list.resp ~ 1, data = lo.inc.Camp,
                        treat = "list.treat", J=3, method = "lm")

summary(camp.list.lo)

camp.list.hi <- ictreg(list.resp ~ 1, data = hi.inc.Camp,
                       treat = "list.treat", J=3, method = "lm")

summary(camp.list.hi)

camp.list.income <- ictreg(list.resp ~ income2, data = data.listCamp,
                       treat = "list.treat", J=3, method = "lm")

summary(camp.list.income)

# Repeat using NLS

camp.list.incomeNLS <- ictreg(list.resp ~ income2, data = data.listCamp,
                           treat = "list.treat", J=3, method = "nls")

summary(camp.list.incomeNLS)

### Org Treatment

org.list.lo <- ictreg(list.resp ~ 1, data = lo.inc.Org,
                       treat = "list.treat", J=3, method = "lm")

summary(org.list.lo)

org.list.hi <- ictreg(list.resp ~ 1, data = hi.inc.Org,
                       treat = "list.treat", J=3, method = "lm")

summary(org.list.hi)

org.list.income <- ictreg(list.resp ~ income2, data = data.listOrg,
                           treat = "list.treat", J=3, method = "lm")

summary(org.list.income)

# Repeat using NLS

org.list.incomeNLS <- ictreg(list.resp ~ income2, data = data.listOrg,
                          treat = "list.treat", J=3, method = "nls")

summary(org.list.incomeNLS)

########## Table 6: Differences in Treatment Effects by Income and Beneficiary Status 

### Campaign Treatment

camp.list.lo.ben <- ictreg(list.resp ~ ben.dum, data = lo.inc.Camp,
                       treat = "list.treat", J=3, method = "lm")
summary(camp.list.lo.ben)


camp.list.lo.pros <- ictreg(list.resp ~ ben.prospera, data = lo.inc.Camp,
                           treat = "list.treat", J=3, method = "lm")
summary(camp.list.lo.pros)


camp.list.lo.non <- ictreg(list.resp ~ ben.non.prospera, data = lo.inc.Camp,
                            treat = "list.treat", J=3, method = "lm")
summary(camp.list.lo.non)


camp.list.hi.ben <- ictreg(list.resp ~ ben.dum, data = hi.inc.Camp,
                           treat = "list.treat", J=3, method = "lm")
summary(camp.list.hi.ben)


camp.list.hi.pros <- ictreg(list.resp ~ ben.prospera, data = hi.inc.Camp,
                            treat = "list.treat", J=3, method = "lm")
summary(camp.list.hi.pros)


camp.list.hi.non <- ictreg(list.resp ~ ben.non.prospera, data = hi.inc.Camp,
                           treat = "list.treat", J=3, method = "lm")
summary(camp.list.hi.non)


### Org Treatment

org.list.lo.ben <- ictreg(list.resp ~ ben.dum, data = lo.inc.Org,
                           treat = "list.treat", J=3, method = "lm")
summary(org.list.lo.ben)


org.list.lo.pros <- ictreg(list.resp ~ ben.prospera, data = lo.inc.Org,
                            treat = "list.treat", J=3, method = "lm")
summary(org.list.lo.pros)


org.list.lo.non <- ictreg(list.resp ~ ben.non.prospera, data = lo.inc.Org,
                           treat = "list.treat", J=3, method = "lm")
summary(org.list.lo.non)


org.list.hi.ben <- ictreg(list.resp ~ ben.dum, data = hi.inc.Org,
                           treat = "list.treat", J=3, method = "lm")
summary(org.list.hi.ben)


org.list.hi.pros <- ictreg(list.resp ~ ben.prospera, data = hi.inc.Org,
                            treat = "list.treat", J=3, method = "lm")
summary(org.list.hi.pros)


org.list.hi.non <- ictreg(list.resp ~ ben.non.prospera, data = hi.inc.Org,
                           treat = "list.treat", J=3, method = "lm")
summary(org.list.hi.non)


########## Table 6 Using NLS

### Campaign Treatment

camp.list.lo.benNLS <- ictreg(list.resp ~ ben.dum, data = lo.inc.Camp,
                           treat = "list.treat", J=3, method = "nls")
summary(camp.list.lo.benNLS)


camp.list.lo.prosNLS <- ictreg(list.resp ~ ben.prospera, data = lo.inc.Camp,
                            treat = "list.treat", J=3, method = "nls")
summary(camp.list.lo.prosNLS)


camp.list.lo.nonNLS <- ictreg(list.resp ~ ben.non.prospera, data = lo.inc.Camp,
                           treat = "list.treat", J=3, method = "nls")
summary(camp.list.lo.nonNLS)


camp.list.hi.benNLS <- ictreg(list.resp ~ ben.dum, data = hi.inc.Camp,
                           treat = "list.treat", J=3, method = "nls")
summary(camp.list.hi.benNLS)


camp.list.hi.prosNLS <- ictreg(list.resp ~ ben.prospera, data = hi.inc.Camp,
                            treat = "list.treat", J=3, method = "nls")
summary(camp.list.hi.prosNLS)


camp.list.hi.nonNLS <- ictreg(list.resp ~ ben.non.prospera, data = hi.inc.Camp,
                           treat = "list.treat", J=3, method = "nls")
summary(camp.list.hi.nonNLS)


### Org Treatment

org.list.lo.benNLS <- ictreg(list.resp ~ ben.dum, data = lo.inc.Org,
                          treat = "list.treat", J=3, method = "nls")
summary(org.list.lo.benNLS)


org.list.lo.prosNLS <- ictreg(list.resp ~ ben.prospera, data = lo.inc.Org,
                           treat = "list.treat", J=3, method = "nls")
summary(org.list.lo.prosNLS)


org.list.lo.nonNLS <- ictreg(list.resp ~ ben.non.prospera, data = lo.inc.Org,
                          treat = "list.treat", J=3, method = "nls")
summary(org.list.lo.nonNLS)


org.list.hi.benNLS <- ictreg(list.resp ~ ben.dum, data = hi.inc.Org,
                          treat = "list.treat", J=3, method = "nls")
summary(org.list.hi.benNLS)


org.list.hi.prosNLS <- ictreg(list.resp ~ ben.prospera, data = hi.inc.Org,
                           treat = "list.treat", J=3, method = "nls")
summary(org.list.hi.prosNLS)


org.list.hi.nonNLS <- ictreg(list.resp ~ ben.non.prospera, data = hi.inc.Org,
                          treat = "list.treat", J=3, method = "nls")
summary(org.list.hi.nonNLS)


########## Table 7: Differences in Treatment Effects by Human Capital for Non-Prospera Beneficiaries

camp.list.ed <- ictreg(list.resp ~ ed, data = data.BenNonProsperaCamp,
                          treat = "list.treat", J=3, method = "lm")
summary(camp.list.ed)

camp.list.sources <- ictreg(list.resp ~ info.sources, data = data.BenNonProsperaCamp,
                       treat = "list.treat", J=3, method = "lm")
summary(camp.list.sources)

camp.list.age <- ictreg(list.resp ~ A1, data = data.BenNonProsperaCamp,
                       treat = "list.treat", J=3, method = "lm")
summary(camp.list.age)

org.list.ed <- ictreg(list.resp ~ ed, data = data.BenNonProsperaOrg,
                       treat = "list.treat", J=3, method = "lm")
summary(org.list.ed)

org.list.sources <- ictreg(list.resp ~ info.sources, data = data.BenNonProsperaOrg,
                            treat = "list.treat", J=3, method = "lm")
summary(org.list.sources)

org.list.age <- ictreg(list.resp ~ A1, data = data.BenNonProsperaOrg,
                        treat = "list.treat", J=3, method = "lm")
summary(org.list.age)


########## Table 8: Organizational Participation by Beneficiary Status

# Org. Member

ddply(data, .(ben.cat), summarise, mean = round(mean(org_mem2, na.rm=T), 4),
      sd = round(sd(org_mem2,na.rm=T), 4))

# Frequency of Participation in Organization

ddply(data, .(ben.cat), summarise, mean = round(mean(org.part.freq, na.rm=T), 4),
      sd = round(sd(org.part.freq,na.rm=T), 4))

# Org. services (from D4B)

ddply(data, .(ben.cat), summarise, mean = round(mean(org.services, na.rm=T), 4),
      sd = round(sd(org.services,na.rm=T), 4))

# Org. gestion (from D4B)
ddply(data, .(ben.cat), summarise, mean = round(mean(D4B.gestion, na.rm=T), 4),
      sd = round(sd(D4B.gestion,na.rm=T), 4))

# Org. collective

ddply(data, .(ben.cat), summarise, mean = round(mean(org.collective, na.rm=T), 4),
      sd = round(sd(org.collective,na.rm=T), 4))

# Linked fate

ddply(data, .(ben.cat), summarise, mean = round(mean(linked.fate, na.rm=T), 4),
      sd = round(sd(linked.fate,na.rm=T), 4))


######################################################################
########## Appendix

# A. Comparing Classes of Beneficiaries on Covariates
# B. Multivariate Analysis
# C. Tables 4, 5, 6 separately for Chiapas and Mexico City
# D. Tables 4, 5, 6 separately for org members and non-members
# E. Tables 5 and 6 with different measures of class 
 
########## Appendix A. Comparing Classes of Beneficiaries on Covariates

# Female
ddply(data, .(ben.cat), summarise, mean = round(mean(female, na.rm=T), 4),
      sd = round(sd(female,na.rm=T), 4))

# Age
ddply(data, .(ben.cat), summarise, mean = round(mean(A1, na.rm=T), 4),
      sd = round(sd(A1,na.rm=T), 4))

# rural50K
ddply(data, .(ben.cat), summarise, mean = round(mean(rural50K, na.rm=T), 4),
      sd = round(sd(rural50K,na.rm=T), 4))

# Indig
ddply(data, .(ben.cat), summarise, mean = round(mean(indig.dum, na.rm=T), 4),
      sd = round(sd(indig.dum,na.rm=T), 4))

# Income
ddply(data, .(ben.cat), summarise, mean = round(mean(income, na.rm=T), 4),
      sd = round(sd(income,na.rm=T), 4))

# Education
ddply(data, .(ben.cat), summarise, mean = round(mean(ed, na.rm=T), 4),
      sd = round(sd(ed,na.rm=T), 4))

# Informal sector
ddply(data, .(ben.cat), summarise, mean = round(mean(employed.informal, na.rm=T), 4), 
      sd = round(sd(employed.informal,na.rm=T), 4))

# Political Participation Index
ddply(data, .(ben.cat), summarise, mean = round(mean(part.index, na.rm=T), 4),
      sd = round(sd(part.index,na.rm=T), 4))

# Participation in Protest
ddply(data, .(ben.cat), summarise, mean = round(mean(manifest, na.rm=T), 4),
      sd = round(sd(manifest,na.rm=T), 4))

# Volunteer
ddply(data, .(ben.cat), summarise, mean = round(mean(volunteer, na.rm=T), 4),
      sd = round(sd(volunteer,na.rm=T), 4))

# Voted in 2015
ddply(data, .(ben.cat), summarise, mean = round(mean(voted.2015, na.rm=T), 4),
      sd = round(sd(voted.2015,na.rm=T), 4))

# Partisan
ddply(data, .(ben.cat), summarise, mean = round(mean(partisan, na.rm=T), 4),
      sd = round(sd(partisan,na.rm=T), 4))

# PRI partisan
ddply(data, .(ben.cat), summarise, mean = round(mean(PRI.dum, na.rm=T), 4),
      sd = round(sd(PRI.dum,na.rm=T), 4))

# Knows somebody exposed to clientelism
ddply(data, .(ben.cat), summarise, mean = round(mean(client, na.rm=T), 4),
      sd = round(sd(client,na.rm=T), 4))

# Sources of political info
ddply(data, .(ben.cat), summarise, mean = round(mean(info.sources, na.rm=T), 4),
      sd = round(sd(info.sources,na.rm=T), 4))



########## Appendix B. Multivariate Analysis

ols.camp1<-ictreg(list.resp~ben.cat,data = data.listCamp, treat = "list.treat", J=3, method = "lm")
summary(ols.camp1)

ols.camp2<-ictreg(list.resp~ben.cat+income+rural50K+Age+indig.dum+estado,data = data.listCamp, treat = "list.treat", J=3, method = "lm")
summary(ols.camp2)

ols.camp3<-ictreg(list.resp~ben.cat+income+rural50K+Age+indig.dum+estado+part.index+partisan+PRI.dum+org_mem2,data = data.listCamp, treat = "list.treat", J=3, method = "lm")
summary(ols.camp3)


ols.org1<-ictreg(list.resp~ben.cat,data = data.listOrg, treat = "list.treat", J=3, method = "lm")
summary(ols.org1)

ols.org2<-ictreg(list.resp~ben.cat+income+rural50K+Age+indig.dum+estado,data = data.listOrg, treat = "list.treat", J=3, method = "lm")
summary(ols.org2)

ols.org3<-ictreg(list.resp~ben.cat+income+rural50K+Age+indig.dum+estado+part.index+partisan+PRI.dum+org_mem2,data = data.listOrg, treat = "list.treat", J=3, method = "lm")
summary(ols.org3)


names(ols.org3)

# To get the N

dim(ols.camp1$data)
dim(ols.camp2$data)
dim(ols.camp3$data)
dim(ols.org1$data)
dim(ols.org2$data)
dim(ols.org3$data)



reg.df<-matrix(NA,24,6)

rownames(reg.df)<-c("Intercept","","Prospera Ben.", "", "Non-Prospera Ben.","","Income","","Rural","","Age","","Indigenous","","State (CDMX)","","Participation Index","","Partisan","","PRI identity","","Org. Member","")

for (i in 1:length(ols.camp1$par.treat)){
  reg.df[seq(1,23,2)[i],1]<-round(ols.camp1$par.treat[[i]],digits=3)
}

for (i in 1:length(ols.camp1$se.treat)){
  reg.df[seq(2,24,2)[i],1]<-paste0("(",format(unlist(round(ols.camp1$se.treat[[i]],digits=3))),")")
}


for (i in 1:length(ols.camp2$par.treat)){
  reg.df[seq(1,23,2)[i],2]<-round(ols.camp2$par.treat[[i]],digits=3)
}

for (i in 1:length(ols.camp2$se.treat)){
  reg.df[seq(2,24,2)[i],2]<-paste0("(",format(unlist(round(ols.camp2$se.treat[[i]],digits=3))),")")
}


for (i in 1:length(ols.camp3$par.treat)){
  reg.df[seq(1,23,2)[i],3]<-round(ols.camp3$par.treat[[i]],digits=3)
}

for (i in 1:length(ols.camp3$se.treat)){
  reg.df[seq(2,24,2)[i],3]<-paste0("(",format(unlist(round(ols.camp3$se.treat[[i]],digits=3))),")")
}


for (i in 1:length(ols.org1$par.treat)){
  reg.df[seq(1,23,2)[i],4]<-round(ols.org1$par.treat[[i]],digits=3)
}

for (i in 1:length(ols.org1$se.treat)){
  reg.df[seq(2,24,2)[i],4]<-paste0("(",format(unlist(round(ols.org1$se.treat[[i]],digits=3))),")")
}

for (i in 1:length(ols.org2$par.treat)){
  reg.df[seq(1,23,2)[i],5]<-round(ols.org2$par.treat[[i]],digits=3)
}

for (i in 1:length(ols.org2$se.treat)){
  reg.df[seq(2,24,2)[i],5]<-paste0("(",format(unlist(round(ols.org2$se.treat[[i]],digits=3))),")")
}


for (i in 1:length(ols.org3$par.treat)){
  reg.df[seq(1,23,2)[i],6]<-round(ols.org3$par.treat[[i]],digits=3)
}

for (i in 1:length(ols.org3$se.treat)){
  reg.df[seq(2,24,2)[i],6]<-paste0("(",format(unlist(round(ols.org3$se.treat[[i]],digits=3))),")")
}


reg.df

xtable(reg.df)


######### Appendix C. Analysis Disaggregated by State

# Table 4, Chiapas

camp.list.ben <- ictreg(list.resp ~ ben.dum, data = data.Camp.Ch,
                        treat = "list.treat", J=3, method = "lm")

camp.list.pros<-ictreg(list.resp ~ ben.prospera, data = data.Camp.Ch,
                       treat = "list.treat", J=3, method = "lm")

camp.list.non<-ictreg(list.resp ~ ben.non.prospera, data = data.Camp.Ch,
                      treat = "list.treat", J=3, method = "lm")

### Org. Treatment

org.list.ben <- ictreg(list.resp ~ ben.dum, data = data.Org.Ch,
                       treat = "list.treat", J=3, method = "lm")

org.list.pros<-ictreg(list.resp ~ ben.prospera, data = data.Org.Ch,
                      treat = "list.treat", J=3, method = "lm")

org.list.non<-ictreg(list.resp ~ ben.non.prospera, data = data.Org.Ch,
                     treat = "list.treat", J=3, method = "lm")

names(camp.list.ben)
camp.list.ben$par.treat[[2]]
camp.list.ben$se.treat[[2]]

tab.a1<-matrix(NA,3,2)
  
rownames(tab.a1)<-c("All Beneficiaries","Prospera Beneficiaries", "Non-Prospera Beneficiaries")

colnames(tab.a1)<-c("Campaign Treatment", "Org. Treatment")

tab.a1[1,1]<-paste0(format(unlist(round(camp.list.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.ben$se.treat[[2]],digits=3))), ")")

tab.a1[2,1]<-paste0(format(unlist(round(camp.list.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.pros$se.treat[[2]],digits=3))), ")")

tab.a1[3,1]<-paste0(format(unlist(round(camp.list.non$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.non$se.treat[[2]],digits=3))), ")")

tab.a1[1,2]<-paste0(format(unlist(round(org.list.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.ben$se.treat[[2]],digits=3))), ")")

tab.a1[2,2]<-paste0(format(unlist(round(org.list.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.pros$se.treat[[2]],digits=3))), ")")

tab.a1[3,2]<-paste0(format(unlist(round(org.list.non$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.non$se.treat[[2]],digits=3))), ")")


tab.a1


# Table 4, DF

camp.list.ben <- ictreg(list.resp ~ ben.dum, data = data.Camp.DF,
                        treat = "list.treat", J=3, method = "lm")

camp.list.pros<-ictreg(list.resp ~ ben.prospera, data = data.Camp.DF,
                       treat = "list.treat", J=3, method = "lm")

camp.list.non<-ictreg(list.resp ~ ben.non.prospera, data = data.Camp.DF,
                      treat = "list.treat", J=3, method = "lm")

### Org. Treatment

org.list.ben <- ictreg(list.resp ~ ben.dum, data = data.Org.DF,
                       treat = "list.treat", J=3, method = "lm")

org.list.pros<-ictreg(list.resp ~ ben.prospera, data = data.Org.DF,
                      treat = "list.treat", J=3, method = "lm")

org.list.non<-ictreg(list.resp ~ ben.non.prospera, data = data.Org.DF,
                     treat = "list.treat", J=3, method = "lm")

names(camp.list.ben)
camp.list.ben$par.treat[[2]]
camp.list.ben$se.treat[[2]]

tab.a2<-matrix(NA,3,2)

rownames(tab.a2)<-c("All Beneficiaries","Prospera Beneficiaries", "Non-Prospera Beneficiaries")

colnames(tab.a2)<-c("Campaign Treatment", "Org. Treatment")

tab.a2[1,1]<-paste0(format(unlist(round(camp.list.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.ben$se.treat[[2]],digits=3))), ")")

tab.a2[2,1]<-paste0(format(unlist(round(camp.list.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.pros$se.treat[[2]],digits=3))), ")")

tab.a2[3,1]<-paste0(format(unlist(round(camp.list.non$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.non$se.treat[[2]],digits=3))), ")")

tab.a2[1,2]<-paste0(format(unlist(round(org.list.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.ben$se.treat[[2]],digits=3))), ")")

tab.a2[2,2]<-paste0(format(unlist(round(org.list.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.pros$se.treat[[2]],digits=3))), ")")

tab.a2[3,2]<-paste0(format(unlist(round(org.list.non$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.non$se.treat[[2]],digits=3))), ")")


tab.a2

# Table 5 Chiapas

### Campaign Treatment

camp.list.lo <- ictreg(list.resp ~ 1, data = lo.inc.Camp.Ch,
                       treat = "list.treat", J=3, method = "lm")

camp.list.hi <- ictreg(list.resp ~ 1, data = hi.inc.Camp.Ch,
                       treat = "list.treat", J=3, method = "lm")

camp.list.income <- ictreg(list.resp ~ income2, data = data.Camp.Ch,
                           treat = "list.treat", J=3, method = "lm")

### Org Treatment

org.list.lo <- ictreg(list.resp ~ 1, data = lo.inc.Org.Ch,
                      treat = "list.treat", J=3, method = "lm")

org.list.hi <- ictreg(list.resp ~ 1, data = hi.inc.Org.Ch,
                      treat = "list.treat", J=3, method = "lm")

org.list.income <- ictreg(list.resp ~ income2, data = data.Org.Ch,
                          treat = "list.treat", J=3, method = "lm")

tab.a3<-matrix(NA,3,2)

rownames(tab.a3)<-c("Low Income","High Income", "Difference btwn. Low and High")

colnames(tab.a3)<-c("Campaign Treatment", "Org. Treatment")

tab.a3[1,1]<-paste0(format(unlist(round(camp.list.lo$par.treat[[1]],digits=3))), " (", format(unlist(round(camp.list.lo$se.treat[[1]],digits=3))), ")")

tab.a3[2,1]<-paste0(format(unlist(round(camp.list.hi$par.treat[[1]],digits=3))), " (", format(unlist(round(camp.list.hi$se.treat[[1]],digits=3))), ")")

tab.a3[3,1]<-paste0(format(unlist(round(camp.list.income$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.income$se.treat[[2]],digits=3))), ")")

tab.a3[1,2]<-paste0(format(unlist(round(org.list.lo$par.treat[[1]],digits=3))), " (", format(unlist(round(org.list.lo$se.treat[[1]],digits=3))), ")")

tab.a3[2,2]<-paste0(format(unlist(round(org.list.hi$par.treat[[1]],digits=3))), " (", format(unlist(round(org.list.hi$se.treat[[1]],digits=3))), ")")

tab.a3[3,2]<-paste0(format(unlist(round(org.list.income$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.income$se.treat[[2]],digits=3))), ")")


tab.a3

# Table 5 DF

### Campaign Treatment

camp.list.lo <- ictreg(list.resp ~ 1, data = lo.inc.Camp.DF,
                       treat = "list.treat", J=3, method = "lm")

camp.list.hi <- ictreg(list.resp ~ 1, data = hi.inc.Camp.DF,
                       treat = "list.treat", J=3, method = "lm")

camp.list.income <- ictreg(list.resp ~ income2, data = data.Camp.DF,
                           treat = "list.treat", J=3, method = "lm")

### Org Treatment

org.list.lo <- ictreg(list.resp ~ 1, data = lo.inc.Org.DF,
                      treat = "list.treat", J=3, method = "lm")

org.list.hi <- ictreg(list.resp ~ 1, data = hi.inc.Org.DF,
                      treat = "list.treat", J=3, method = "lm")

org.list.income <- ictreg(list.resp ~ income2, data = data.Org.DF,
                          treat = "list.treat", J=3, method = "lm")

tab.a4<-matrix(NA,3,2)

rownames(tab.a4)<-c("Low Income","High Income", "Difference btwn. Low and High")

colnames(tab.a4)<-c("Campaign Treatment", "Org. Treatment")

tab.a4[1,1]<-paste0(format(unlist(round(camp.list.lo$par.treat[[1]],digits=3))), " (", format(unlist(round(camp.list.lo$se.treat[[1]],digits=3))), ")")

tab.a4[2,1]<-paste0(format(unlist(round(camp.list.hi$par.treat[[1]],digits=3))), " (", format(unlist(round(camp.list.hi$se.treat[[1]],digits=3))), ")")

tab.a4[3,1]<-paste0(format(unlist(round(camp.list.income$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.income$se.treat[[2]],digits=3))), ")")

tab.a4[1,2]<-paste0(format(unlist(round(org.list.lo$par.treat[[1]],digits=3))), " (", format(unlist(round(org.list.lo$se.treat[[1]],digits=3))), ")")

tab.a4[2,2]<-paste0(format(unlist(round(org.list.hi$par.treat[[1]],digits=3))), " (", format(unlist(round(org.list.hi$se.treat[[1]],digits=3))), ")")

tab.a4[3,2]<-paste0(format(unlist(round(org.list.income$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.income$se.treat[[2]],digits=3))), ")")


tab.a4

# Table 6 Chiapas

### Campaign Treatment

camp.list.lo.ben <- ictreg(list.resp ~ ben.dum, data = lo.inc.Camp.Ch,
                           treat = "list.treat", J=3, method = "lm")

camp.list.lo.pros <- ictreg(list.resp ~ ben.prospera, data = lo.inc.Camp.Ch,
                            treat = "list.treat", J=3, method = "lm")

camp.list.lo.non <- ictreg(list.resp ~ ben.non.prospera, data = lo.inc.Camp.Ch,
                           treat = "list.treat", J=3, method = "lm")

camp.list.hi.ben <- ictreg(list.resp ~ ben.dum, data = hi.inc.Camp.Ch,
                           treat = "list.treat", J=3, method = "lm")

camp.list.hi.pros <- ictreg(list.resp ~ ben.prospera, data = hi.inc.Camp.Ch,
                            treat = "list.treat", J=3, method = "lm")

camp.list.hi.non <- ictreg(list.resp ~ ben.non.prospera, data = hi.inc.Camp.Ch,
                           treat = "list.treat", J=3, method = "lm")

### Org Treatment

org.list.lo.ben <- ictreg(list.resp ~ ben.dum, data = lo.inc.Org.Ch,
                          treat = "list.treat", J=3, method = "lm")

org.list.lo.pros <- ictreg(list.resp ~ ben.prospera, data = lo.inc.Org.Ch,
                           treat = "list.treat", J=3, method = "lm")

org.list.lo.non <- ictreg(list.resp ~ ben.non.prospera, data = lo.inc.Org.Ch,
                          treat = "list.treat", J=3, method = "lm")

org.list.hi.ben <- ictreg(list.resp ~ ben.dum, data = hi.inc.Org.Ch,
                          treat = "list.treat", J=3, method = "lm")

org.list.hi.pros <- ictreg(list.resp ~ ben.prospera, data = hi.inc.Org.Ch,
                           treat = "list.treat", J=3, method = "lm")

org.list.hi.non <- ictreg(list.resp ~ ben.non.prospera, data = hi.inc.Org.Ch,
                          treat = "list.treat", J=3, method = "lm")

tab.a5<-matrix(NA,6,2)

rownames(tab.a5)<-c("All Beneficiaries","Prospera Beneficiaries", "Non-Prospera Beneficiaries", "All Beneficiaries","Prospera Beneficiaries", "Non-Prospera Beneficiaries")

colnames(tab.a5)<-c("Campaign Treatment", "Org. Treatment")

tab.a5[1,1]<-paste0(format(unlist(round(camp.list.lo.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.lo.ben$se.treat[[2]],digits=3))), ")")

tab.a5[2,1]<-paste0(format(unlist(round(camp.list.lo.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.lo.pros$se.treat[[2]],digits=3))), ")")

tab.a5[3,1]<-paste0(format(unlist(round(camp.list.lo.non$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.lo.non$se.treat[[2]],digits=3))), ")")


tab.a5[4,1]<-paste0(format(unlist(round(camp.list.hi.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.hi.ben$se.treat[[2]],digits=3))), ")")

tab.a5[5,1]<-paste0(format(unlist(round(camp.list.hi.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.hi.pros$se.treat[[2]],digits=3))), ")")

tab.a5[6,1]<-paste0(format(unlist(round(camp.list.hi.non$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.hi.non$se.treat[[2]],digits=3))), ")")

tab.a5[1,2]<-paste0(format(unlist(round(org.list.lo.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.lo.ben$se.treat[[2]],digits=3))), ")")

tab.a5[2,2]<-paste0(format(unlist(round(org.list.lo.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.lo.pros$se.treat[[2]],digits=3))), ")")

tab.a5[3,2]<-paste0(format(unlist(round(org.list.lo.non$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.lo.non$se.treat[[2]],digits=3))), ")")


tab.a5[4,2]<-paste0(format(unlist(round(org.list.hi.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.hi.ben$se.treat[[2]],digits=3))), ")")

tab.a5[5,2]<-paste0(format(unlist(round(org.list.hi.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.hi.pros$se.treat[[2]],digits=3))), ")")

tab.a5[6,2]<-paste0(format(unlist(round(org.list.hi.non$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.hi.non$se.treat[[2]],digits=3))), ")")

tab.a5

# Table 6 DF

### Campaign Treatment

camp.list.lo.ben <- ictreg(list.resp ~ ben.dum, data = lo.inc.Camp.DF,
                           treat = "list.treat", J=3, method = "lm")

camp.list.lo.pros <- ictreg(list.resp ~ ben.prospera, data = lo.inc.Camp.DF,
                            treat = "list.treat", J=3, method = "lm")

camp.list.lo.non <- ictreg(list.resp ~ ben.non.prospera, data = lo.inc.Camp.DF,
                           treat = "list.treat", J=3, method = "lm")

camp.list.hi.ben <- ictreg(list.resp ~ ben.dum, data = hi.inc.Camp.DF,
                           treat = "list.treat", J=3, method = "lm")

camp.list.hi.pros <- ictreg(list.resp ~ ben.prospera, data = hi.inc.Camp.DF,
                            treat = "list.treat", J=3, method = "lm")

camp.list.hi.non <- ictreg(list.resp ~ ben.non.prospera, data = hi.inc.Camp.DF,
                           treat = "list.treat", J=3, method = "lm")

### Org Treatment

org.list.lo.ben <- ictreg(list.resp ~ ben.dum, data = lo.inc.Org.DF,
                          treat = "list.treat", J=3, method = "lm")

org.list.lo.pros <- ictreg(list.resp ~ ben.prospera, data = lo.inc.Org.DF,
                           treat = "list.treat", J=3, method = "lm")

org.list.lo.non <- ictreg(list.resp ~ ben.non.prospera, data = lo.inc.Org.DF,
                          treat = "list.treat", J=3, method = "lm")

org.list.hi.ben <- ictreg(list.resp ~ ben.dum, data = hi.inc.Org.DF,
                          treat = "list.treat", J=3, method = "lm")

org.list.hi.pros <- ictreg(list.resp ~ ben.prospera, data = hi.inc.Org.DF,
                           treat = "list.treat", J=3, method = "lm")

org.list.hi.non <- ictreg(list.resp ~ ben.non.prospera, data = hi.inc.Org.DF,
                          treat = "list.treat", J=3, method = "lm")

tab.a6<-matrix(NA,6,2)

rownames(tab.a6)<-c("All Beneficiaries","Prospera Beneficiaries", "Non-Prospera Beneficiaries", "All Beneficiaries","Prospera Beneficiaries", "Non-Prospera Beneficiaries")

colnames(tab.a6)<-c("Campaign Treatment", "Org. Treatment")

tab.a6[1,1]<-paste0(format(unlist(round(camp.list.lo.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.lo.ben$se.treat[[2]],digits=3))), ")")

tab.a6[2,1]<-paste0(format(unlist(round(camp.list.lo.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.lo.pros$se.treat[[2]],digits=3))), ")")

tab.a6[3,1]<-paste0(format(unlist(round(camp.list.lo.non$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.lo.non$se.treat[[2]],digits=3))), ")")


tab.a6[4,1]<-paste0(format(unlist(round(camp.list.hi.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.hi.ben$se.treat[[2]],digits=3))), ")")

tab.a6[5,1]<-paste0(format(unlist(round(camp.list.hi.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.hi.pros$se.treat[[2]],digits=3))), ")")

tab.a6[6,1]<-paste0(format(unlist(round(camp.list.hi.non$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.hi.non$se.treat[[2]],digits=3))), ")")

tab.a6[1,2]<-paste0(format(unlist(round(org.list.lo.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.lo.ben$se.treat[[2]],digits=3))), ")")

tab.a6[2,2]<-paste0(format(unlist(round(org.list.lo.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.lo.pros$se.treat[[2]],digits=3))), ")")

tab.a6[3,2]<-paste0(format(unlist(round(org.list.lo.non$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.lo.non$se.treat[[2]],digits=3))), ")")


tab.a6[4,2]<-paste0(format(unlist(round(org.list.hi.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.hi.ben$se.treat[[2]],digits=3))), ")")

tab.a6[5,2]<-paste0(format(unlist(round(org.list.hi.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.hi.pros$se.treat[[2]],digits=3))), ")")

tab.a6[6,2]<-paste0(format(unlist(round(org.list.hi.non$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.hi.non$se.treat[[2]],digits=3))), ")")

tab.a6



######### Appendix D. Analysis Disaggregated by Membership Status

# Table 4, Members

camp.list.ben <- ictreg(list.resp ~ ben.dum, data = data.membCamp,
                        treat = "list.treat", J=3, method = "lm")

camp.list.pros<-ictreg(list.resp ~ ben.prospera, data = data.membCamp,
                       treat = "list.treat", J=3, method = "lm")

camp.list.non<-ictreg(list.resp ~ ben.non.prospera, data = data.membCamp,
                      treat = "list.treat", J=3, method = "lm")

### Org. Treatment

org.list.ben <- ictreg(list.resp ~ ben.dum, data = data.membOrg,
                       treat = "list.treat", J=3, method = "lm")

org.list.pros<-ictreg(list.resp ~ ben.prospera, data = data.membOrg,
                      treat = "list.treat", J=3, method = "lm")

org.list.non<-ictreg(list.resp ~ ben.non.prospera, data = data.membOrg,
                     treat = "list.treat", J=3, method = "lm")

names(camp.list.ben)
camp.list.ben$par.treat[[2]]
camp.list.ben$se.treat[[2]]

tab.a7<-matrix(NA,3,2)

rownames(tab.a7)<-c("All Beneficiaries","Prospera Beneficiaries", "Non-Prospera Beneficiaries")

colnames(tab.a7)<-c("Campaign Treatment", "Org. Treatment")

tab.a7[1,1]<-paste0(format(unlist(round(camp.list.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.ben$se.treat[[2]],digits=3))), ")")

tab.a7[2,1]<-paste0(format(unlist(round(camp.list.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.pros$se.treat[[2]],digits=3))), ")")

tab.a7[3,1]<-paste0(format(unlist(round(camp.list.non$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.non$se.treat[[2]],digits=3))), ")")

tab.a7[1,2]<-paste0(format(unlist(round(org.list.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.ben$se.treat[[2]],digits=3))), ")")

tab.a7[2,2]<-paste0(format(unlist(round(org.list.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.pros$se.treat[[2]],digits=3))), ")")

tab.a7[3,2]<-paste0(format(unlist(round(org.list.non$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.non$se.treat[[2]],digits=3))), ")")


tab.a7


# Table 4, Non-Memb

camp.list.ben <- ictreg(list.resp ~ ben.dum, data = data.nonmembCamp,
                        treat = "list.treat", J=3, method = "lm")

camp.list.pros<-ictreg(list.resp ~ ben.prospera, data = data.nonmembCamp,
                       treat = "list.treat", J=3, method = "lm")

camp.list.non<-ictreg(list.resp ~ ben.non.prospera, data = data.nonmembCamp,
                      treat = "list.treat", J=3, method = "lm")

### Org. Treatment

org.list.ben <- ictreg(list.resp ~ ben.dum, data = data.nonmembOrg,
                       treat = "list.treat", J=3, method = "lm")

org.list.pros<-ictreg(list.resp ~ ben.prospera, data = data.nonmembOrg,
                      treat = "list.treat", J=3, method = "lm")

org.list.non<-ictreg(list.resp ~ ben.non.prospera, data = data.nonmembOrg,
                     treat = "list.treat", J=3, method = "lm")

names(camp.list.ben)
camp.list.ben$par.treat[[2]]
camp.list.ben$se.treat[[2]]

tab.a8<-matrix(NA,3,2)

rownames(tab.a8)<-c("All Beneficiaries","Prospera Beneficiaries", "Non-Prospera Beneficiaries")

colnames(tab.a8)<-c("Campaign Treatment", "Org. Treatment")

tab.a8[1,1]<-paste0(format(unlist(round(camp.list.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.ben$se.treat[[2]],digits=3))), ")")

tab.a8[2,1]<-paste0(format(unlist(round(camp.list.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.pros$se.treat[[2]],digits=3))), ")")

tab.a8[3,1]<-paste0(format(unlist(round(camp.list.non$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.non$se.treat[[2]],digits=3))), ")")

tab.a8[1,2]<-paste0(format(unlist(round(org.list.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.ben$se.treat[[2]],digits=3))), ")")

tab.a8[2,2]<-paste0(format(unlist(round(org.list.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.pros$se.treat[[2]],digits=3))), ")")

tab.a8[3,2]<-paste0(format(unlist(round(org.list.non$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.non$se.treat[[2]],digits=3))), ")")


tab.a8



# Table 5 Membs

### Campaign Treatment

camp.list.lo <- ictreg(list.resp ~ 1, data = lo.inc.Camp.memb,
                       treat = "list.treat", J=3, method = "lm")

camp.list.hi <- ictreg(list.resp ~ 1, data = hi.inc.Camp.memb,
                       treat = "list.treat", J=3, method = "lm")

camp.list.income <- ictreg(list.resp ~ income2, data = data.membCamp,
                           treat = "list.treat", J=3, method = "lm")

### Org Treatment

org.list.lo <- ictreg(list.resp ~ 1, data = lo.inc.Org.memb,
                      treat = "list.treat", J=3, method = "lm")

org.list.hi <- ictreg(list.resp ~ 1, data = hi.inc.Org.memb,
                      treat = "list.treat", J=3, method = "lm")

org.list.income <- ictreg(list.resp ~ income2, data = data.membOrg,
                          treat = "list.treat", J=3, method = "lm")

tab.a9<-matrix(NA,3,2)

rownames(tab.a9)<-c("Low Income","High Income", "Difference btwn. Low and High")

colnames(tab.a9)<-c("Campaign Treatment", "Org. Treatment")

tab.a9[1,1]<-paste0(format(unlist(round(camp.list.lo$par.treat[[1]],digits=3))), " (", format(unlist(round(camp.list.lo$se.treat[[1]],digits=3))), ")")

tab.a9[2,1]<-paste0(format(unlist(round(camp.list.hi$par.treat[[1]],digits=3))), " (", format(unlist(round(camp.list.hi$se.treat[[1]],digits=3))), ")")

tab.a9[3,1]<-paste0(format(unlist(round(camp.list.income$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.income$se.treat[[2]],digits=3))), ")")

tab.a9[1,2]<-paste0(format(unlist(round(org.list.lo$par.treat[[1]],digits=3))), " (", format(unlist(round(org.list.lo$se.treat[[1]],digits=3))), ")")

tab.a9[2,2]<-paste0(format(unlist(round(org.list.hi$par.treat[[1]],digits=3))), " (", format(unlist(round(org.list.hi$se.treat[[1]],digits=3))), ")")

tab.a9[3,2]<-paste0(format(unlist(round(org.list.income$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.income$se.treat[[2]],digits=3))), ")")


tab.a9

# Table 5 Non-Membs

### Campaign Treatment

camp.list.lo <- ictreg(list.resp ~ 1, data = lo.inc.Camp.nonmemb,
                       treat = "list.treat", J=3, method = "lm")

camp.list.hi <- ictreg(list.resp ~ 1, data = hi.inc.Camp.nonmemb,
                       treat = "list.treat", J=3, method = "lm")

camp.list.income <- ictreg(list.resp ~ income2, data = data.nonmembCamp,
                           treat = "list.treat", J=3, method = "lm")

### Org Treatment

org.list.lo <- ictreg(list.resp ~ 1, data = lo.inc.Org.nonmemb,
                      treat = "list.treat", J=3, method = "lm")

org.list.hi <- ictreg(list.resp ~ 1, data = hi.inc.Org.nonmemb,
                      treat = "list.treat", J=3, method = "lm")

org.list.income <- ictreg(list.resp ~ income2, data = data.nonmembOrg,
                          treat = "list.treat", J=3, method = "lm")

tab.a10<-matrix(NA,3,2)

rownames(tab.a10)<-c("Low Income","High Income", "Difference btwn. Low and High")

colnames(tab.a10)<-c("Campaign Treatment", "Org. Treatment")

tab.a10[1,1]<-paste0(format(unlist(round(camp.list.lo$par.treat[[1]],digits=3))), " (", format(unlist(round(camp.list.lo$se.treat[[1]],digits=3))), ")")

tab.a10[2,1]<-paste0(format(unlist(round(camp.list.hi$par.treat[[1]],digits=3))), " (", format(unlist(round(camp.list.hi$se.treat[[1]],digits=3))), ")")

tab.a10[3,1]<-paste0(format(unlist(round(camp.list.income$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.income$se.treat[[2]],digits=3))), ")")

tab.a10[1,2]<-paste0(format(unlist(round(org.list.lo$par.treat[[1]],digits=3))), " (", format(unlist(round(org.list.lo$se.treat[[1]],digits=3))), ")")

tab.a10[2,2]<-paste0(format(unlist(round(org.list.hi$par.treat[[1]],digits=3))), " (", format(unlist(round(org.list.hi$se.treat[[1]],digits=3))), ")")

tab.a10[3,2]<-paste0(format(unlist(round(org.list.income$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.income$se.treat[[2]],digits=3))), ")")


tab.a10


# Table 6 Membs

### Campaign Treatment

camp.list.lo.ben <- ictreg(list.resp ~ ben.dum, data = lo.inc.Camp.memb,
                           treat = "list.treat", J=3, method = "lm")

camp.list.lo.pros <- ictreg(list.resp ~ ben.prospera, data = lo.inc.Camp.memb,
                            treat = "list.treat", J=3, method = "lm")

camp.list.lo.non <- ictreg(list.resp ~ ben.non.prospera, data = lo.inc.Camp.memb,
                           treat = "list.treat", J=3, method = "lm")

camp.list.hi.ben <- ictreg(list.resp ~ ben.dum, data = hi.inc.Camp.memb,
                           treat = "list.treat", J=3, method = "lm")

camp.list.hi.pros <- ictreg(list.resp ~ ben.prospera, data = hi.inc.Camp.memb,
                            treat = "list.treat", J=3, method = "lm")

camp.list.hi.non <- ictreg(list.resp ~ ben.non.prospera, data = hi.inc.Camp.memb,
                           treat = "list.treat", J=3, method = "lm")

### Org Treatment

org.list.lo.ben <- ictreg(list.resp ~ ben.dum, data = lo.inc.Org.memb,
                          treat = "list.treat", J=3, method = "lm")

org.list.lo.pros <- ictreg(list.resp ~ ben.prospera, data = lo.inc.Org.memb,
                           treat = "list.treat", J=3, method = "lm")

org.list.lo.non <- ictreg(list.resp ~ ben.non.prospera, data = lo.inc.Org.memb,
                          treat = "list.treat", J=3, method = "lm")

org.list.hi.ben <- ictreg(list.resp ~ ben.dum, data = hi.inc.Org.memb,
                          treat = "list.treat", J=3, method = "lm")

org.list.hi.pros <- ictreg(list.resp ~ ben.prospera, data = hi.inc.Org.memb,
                           treat = "list.treat", J=3, method = "lm")

org.list.hi.non <- ictreg(list.resp ~ ben.non.prospera, data = hi.inc.Org.memb,
                          treat = "list.treat", J=3, method = "lm")

tab.a11<-matrix(NA,6,2)

rownames(tab.a11)<-c("All Beneficiaries","Prospera Beneficiaries", "Non-Prospera Beneficiaries", "All Beneficiaries","Prospera Beneficiaries", "Non-Prospera Beneficiaries")

colnames(tab.a11)<-c("Campaign Treatment", "Org. Treatment")

tab.a11[1,1]<-paste0(format(unlist(round(camp.list.lo.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.lo.ben$se.treat[[2]],digits=3))), ")")

tab.a11[2,1]<-paste0(format(unlist(round(camp.list.lo.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.lo.pros$se.treat[[2]],digits=3))), ")")

tab.a11[3,1]<-paste0(format(unlist(round(camp.list.lo.non$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.lo.non$se.treat[[2]],digits=3))), ")")


tab.a11[4,1]<-paste0(format(unlist(round(camp.list.hi.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.hi.ben$se.treat[[2]],digits=3))), ")")

tab.a11[5,1]<-paste0(format(unlist(round(camp.list.hi.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.hi.pros$se.treat[[2]],digits=3))), ")")

tab.a11[6,1]<-paste0(format(unlist(round(camp.list.hi.non$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.hi.non$se.treat[[2]],digits=3))), ")")

tab.a11[1,2]<-paste0(format(unlist(round(org.list.lo.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.lo.ben$se.treat[[2]],digits=3))), ")")

tab.a11[2,2]<-paste0(format(unlist(round(org.list.lo.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.lo.pros$se.treat[[2]],digits=3))), ")")

tab.a11[3,2]<-paste0(format(unlist(round(org.list.lo.non$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.lo.non$se.treat[[2]],digits=3))), ")")


tab.a11[4,2]<-paste0(format(unlist(round(org.list.hi.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.hi.ben$se.treat[[2]],digits=3))), ")")

tab.a11[5,2]<-paste0(format(unlist(round(org.list.hi.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.hi.pros$se.treat[[2]],digits=3))), ")")

tab.a11[6,2]<-paste0(format(unlist(round(org.list.hi.non$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.hi.non$se.treat[[2]],digits=3))), ")")

tab.a11

# Table 6 Non-membs

### Campaign Treatment

camp.list.lo.ben <- ictreg(list.resp ~ ben.dum, data = lo.inc.Camp.nonmemb,
                           treat = "list.treat", J=3, method = "lm")

camp.list.lo.pros <- ictreg(list.resp ~ ben.prospera, data = lo.inc.Camp.nonmemb,
                            treat = "list.treat", J=3, method = "lm")

camp.list.lo.non <- ictreg(list.resp ~ ben.non.prospera, data = lo.inc.Camp.nonmemb,
                           treat = "list.treat", J=3, method = "lm")

camp.list.hi.ben <- ictreg(list.resp ~ ben.dum, data = hi.inc.Camp.nonmemb,
                           treat = "list.treat", J=3, method = "lm")

camp.list.hi.pros <- ictreg(list.resp ~ ben.prospera, data = hi.inc.Camp.nonmemb,
                            treat = "list.treat", J=3, method = "lm")

camp.list.hi.non <- ictreg(list.resp ~ ben.non.prospera, data = hi.inc.Camp.nonmemb,
                           treat = "list.treat", J=3, method = "lm")

### Org Treatment

org.list.lo.ben <- ictreg(list.resp ~ ben.dum, data = lo.inc.Org.nonmemb,
                          treat = "list.treat", J=3, method = "lm")

org.list.lo.pros <- ictreg(list.resp ~ ben.prospera, data = lo.inc.Org.nonmemb,
                           treat = "list.treat", J=3, method = "lm")

org.list.lo.non <- ictreg(list.resp ~ ben.non.prospera, data = lo.inc.Org.nonmemb,
                          treat = "list.treat", J=3, method = "lm")

org.list.hi.ben <- ictreg(list.resp ~ ben.dum, data = hi.inc.Org.nonmemb,
                          treat = "list.treat", J=3, method = "lm")

org.list.hi.pros <- ictreg(list.resp ~ ben.prospera, data = hi.inc.Org.nonmemb,
                           treat = "list.treat", J=3, method = "lm")

org.list.hi.non <- ictreg(list.resp ~ ben.non.prospera, data = hi.inc.Org.nonmemb,
                          treat = "list.treat", J=3, method = "lm")

tab.a12<-matrix(NA,6,2)

rownames(tab.a12)<-c("All Beneficiaries","Prospera Beneficiaries", "Non-Prospera Beneficiaries", "All Beneficiaries","Prospera Beneficiaries", "Non-Prospera Beneficiaries")

colnames(tab.a12)<-c("Campaign Treatment", "Org. Treatment")

tab.a12[1,1]<-paste0(format(unlist(round(camp.list.lo.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.lo.ben$se.treat[[2]],digits=3))), ")")

tab.a12[2,1]<-paste0(format(unlist(round(camp.list.lo.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.lo.pros$se.treat[[2]],digits=3))), ")")

tab.a12[3,1]<-paste0(format(unlist(round(camp.list.lo.non$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.lo.non$se.treat[[2]],digits=3))), ")")


tab.a12[4,1]<-paste0(format(unlist(round(camp.list.hi.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.hi.ben$se.treat[[2]],digits=3))), ")")

tab.a12[5,1]<-paste0(format(unlist(round(camp.list.hi.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.hi.pros$se.treat[[2]],digits=3))), ")")

tab.a12[6,1]<-paste0(format(unlist(round(camp.list.hi.non$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.hi.non$se.treat[[2]],digits=3))), ")")

tab.a12[1,2]<-paste0(format(unlist(round(org.list.lo.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.lo.ben$se.treat[[2]],digits=3))), ")")

tab.a12[2,2]<-paste0(format(unlist(round(org.list.lo.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.lo.pros$se.treat[[2]],digits=3))), ")")

tab.a12[3,2]<-paste0(format(unlist(round(org.list.lo.non$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.lo.non$se.treat[[2]],digits=3))), ")")


tab.a12[4,2]<-paste0(format(unlist(round(org.list.hi.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.hi.ben$se.treat[[2]],digits=3))), ")")

tab.a12[5,2]<-paste0(format(unlist(round(org.list.hi.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.hi.pros$se.treat[[2]],digits=3))), ")")

tab.a12[6,2]<-paste0(format(unlist(round(org.list.hi.non$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.hi.non$se.treat[[2]],digits=3))), ")")

tab.a12



########## Appendix E: Reproduce Analysis for Alternative Measures of Class

#1. State-based income measure
#2. Education
#3. Poverty (Occupancy rate)
#4. Rural vs. Urban Municipality

table(data$income2.state)
table(data$ed2)
table(data$occ.rate2)
table(data$rural50K)


########1. State-Based Measure

# For high and low income
lo.inc.Camp<-data.listCamp[data.listCamp$income2.state=="low",]
dim(lo.inc.Camp)

hi.inc.Camp<-data.listCamp[data.listCamp$income2.state=="high",]
dim(hi.inc.Camp)

lo.inc.Org<-data.listOrg[data.listOrg$income2.state=="low",]
dim(lo.inc.Org)

hi.inc.Org<-data.listOrg[data.listOrg$income2.state=="high",]
dim(hi.inc.Org)

##### Table 5

### Campaign Treatment

camp.list.lo <- ictreg(list.resp ~ 1, data = lo.inc.Camp,
                       treat = "list.treat", J=3, method = "lm")

camp.list.hi <- ictreg(list.resp ~ 1, data = hi.inc.Camp,
                       treat = "list.treat", J=3, method = "lm")

camp.list.income <- ictreg(list.resp ~ income2.state, data = data.listCamp,
                           treat = "list.treat", J=3, method = "lm")

### Org Treatment

org.list.lo <- ictreg(list.resp ~ 1, data = lo.inc.Org,
                      treat = "list.treat", J=3, method = "lm")

org.list.hi <- ictreg(list.resp ~ 1, data = hi.inc.Org,
                      treat = "list.treat", J=3, method = "lm")

org.list.income <- ictreg(list.resp ~ income2.state, data = data.listOrg,
                          treat = "list.treat", J=3, method = "lm")

tab.a13<-matrix(NA,3,2)

rownames(tab.a13)<-c("Low Income","High Income", "Difference btwn. Low and High")

colnames(tab.a13)<-c("Campaign Treatment", "Org. Treatment")

tab.a13[1,1]<-paste0(format(unlist(round(camp.list.lo$par.treat[[1]],digits=3))), " (", format(unlist(round(camp.list.lo$se.treat[[1]],digits=3))), ")")

tab.a13[2,1]<-paste0(format(unlist(round(camp.list.hi$par.treat[[1]],digits=3))), " (", format(unlist(round(camp.list.hi$se.treat[[1]],digits=3))), ")")

tab.a13[3,1]<-paste0(format(unlist(round(camp.list.income$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.income$se.treat[[2]],digits=3))), ")")

tab.a13[1,2]<-paste0(format(unlist(round(org.list.lo$par.treat[[1]],digits=3))), " (", format(unlist(round(org.list.lo$se.treat[[1]],digits=3))), ")")

tab.a13[2,2]<-paste0(format(unlist(round(org.list.hi$par.treat[[1]],digits=3))), " (", format(unlist(round(org.list.hi$se.treat[[1]],digits=3))), ")")

tab.a13[3,2]<-paste0(format(unlist(round(org.list.income$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.income$se.treat[[2]],digits=3))), ")")


tab.a13


########## Table 6

### Campaign Treatment

camp.list.lo.ben <- ictreg(list.resp ~ ben.dum, data = lo.inc.Camp,
                           treat = "list.treat", J=3, method = "lm")

camp.list.lo.pros <- ictreg(list.resp ~ ben.prospera, data = lo.inc.Camp,
                            treat = "list.treat", J=3, method = "lm")

camp.list.lo.non <- ictreg(list.resp ~ ben.non.prospera, data = lo.inc.Camp,
                           treat = "list.treat", J=3, method = "lm")

camp.list.hi.ben <- ictreg(list.resp ~ ben.dum, data = hi.inc.Camp,
                           treat = "list.treat", J=3, method = "lm")

camp.list.hi.pros <- ictreg(list.resp ~ ben.prospera, data = hi.inc.Camp,
                            treat = "list.treat", J=3, method = "lm")

camp.list.hi.non <- ictreg(list.resp ~ ben.non.prospera, data = hi.inc.Camp,
                           treat = "list.treat", J=3, method = "lm")

### Org Treatment

org.list.lo.ben <- ictreg(list.resp ~ ben.dum, data = lo.inc.Org,
                          treat = "list.treat", J=3, method = "lm")

org.list.lo.pros <- ictreg(list.resp ~ ben.prospera, data = lo.inc.Org,
                           treat = "list.treat", J=3, method = "lm")

org.list.lo.non <- ictreg(list.resp ~ ben.non.prospera, data = lo.inc.Org,
                          treat = "list.treat", J=3, method = "lm")

org.list.hi.ben <- ictreg(list.resp ~ ben.dum, data = hi.inc.Org,
                          treat = "list.treat", J=3, method = "lm")

org.list.hi.pros <- ictreg(list.resp ~ ben.prospera, data = hi.inc.Org,
                           treat = "list.treat", J=3, method = "lm")

org.list.hi.non <- ictreg(list.resp ~ ben.non.prospera, data = hi.inc.Org,
                          treat = "list.treat", J=3, method = "lm")

tab.a14<-matrix(NA,6,2)

rownames(tab.a14)<-c("All Beneficiaries","Prospera Beneficiaries", "Non-Prospera Beneficiaries", "All Beneficiaries","Prospera Beneficiaries", "Non-Prospera Beneficiaries")

colnames(tab.a14)<-c("Campaign Treatment", "Org. Treatment")

tab.a14[1,1]<-paste0(format(unlist(round(camp.list.lo.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.lo.ben$se.treat[[2]],digits=3))), ")")

tab.a14[2,1]<-paste0(format(unlist(round(camp.list.lo.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.lo.pros$se.treat[[2]],digits=3))), ")")

tab.a14[3,1]<-paste0(format(unlist(round(camp.list.lo.non$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.lo.non$se.treat[[2]],digits=3))), ")")


tab.a14[4,1]<-paste0(format(unlist(round(camp.list.hi.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.hi.ben$se.treat[[2]],digits=3))), ")")

tab.a14[5,1]<-paste0(format(unlist(round(camp.list.hi.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.hi.pros$se.treat[[2]],digits=3))), ")")

tab.a14[6,1]<-paste0(format(unlist(round(camp.list.hi.non$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.hi.non$se.treat[[2]],digits=3))), ")")

tab.a14[1,2]<-paste0(format(unlist(round(org.list.lo.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.lo.ben$se.treat[[2]],digits=3))), ")")

tab.a14[2,2]<-paste0(format(unlist(round(org.list.lo.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.lo.pros$se.treat[[2]],digits=3))), ")")

tab.a14[3,2]<-paste0(format(unlist(round(org.list.lo.non$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.lo.non$se.treat[[2]],digits=3))), ")")


tab.a14[4,2]<-paste0(format(unlist(round(org.list.hi.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.hi.ben$se.treat[[2]],digits=3))), ")")

tab.a14[5,2]<-paste0(format(unlist(round(org.list.hi.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.hi.pros$se.treat[[2]],digits=3))), ")")

tab.a14[6,2]<-paste0(format(unlist(round(org.list.hi.non$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.hi.non$se.treat[[2]],digits=3))), ")")

tab.a14


######## 2. Education

# For high and low income
lo.inc.Camp<-data.listCamp[data.listCamp$ed2=="low",]
dim(lo.inc.Camp)

hi.inc.Camp<-data.listCamp[data.listCamp$ed2=="high",]
dim(hi.inc.Camp)

lo.inc.Org<-data.listOrg[data.listOrg$ed2=="low",]
dim(lo.inc.Org)

hi.inc.Org<-data.listOrg[data.listOrg$ed2=="high",]
dim(hi.inc.Org)

##### Table 5

### Campaign Treatment

camp.list.lo <- ictreg(list.resp ~ 1, data = lo.inc.Camp,
                       treat = "list.treat", J=3, method = "lm")

camp.list.hi <- ictreg(list.resp ~ 1, data = hi.inc.Camp,
                       treat = "list.treat", J=3, method = "lm")

camp.list.income <- ictreg(list.resp ~ ed2, data = data.listCamp,
                           treat = "list.treat", J=3, method = "lm")

### Org Treatment

org.list.lo <- ictreg(list.resp ~ 1, data = lo.inc.Org,
                      treat = "list.treat", J=3, method = "lm")

org.list.hi <- ictreg(list.resp ~ 1, data = hi.inc.Org,
                      treat = "list.treat", J=3, method = "lm")

org.list.income <- ictreg(list.resp ~ ed2, data = data.listOrg,
                          treat = "list.treat", J=3, method = "lm")

tab.a15<-matrix(NA,3,2)

rownames(tab.a15)<-c("Low Income","High Income", "Difference btwn. Low and High")

colnames(tab.a15)<-c("Campaign Treatment", "Org. Treatment")

tab.a15[1,1]<-paste0(format(unlist(round(camp.list.lo$par.treat[[1]],digits=3))), " (", format(unlist(round(camp.list.lo$se.treat[[1]],digits=3))), ")")

tab.a15[2,1]<-paste0(format(unlist(round(camp.list.hi$par.treat[[1]],digits=3))), " (", format(unlist(round(camp.list.hi$se.treat[[1]],digits=3))), ")")

tab.a15[3,1]<-paste0(format(unlist(round(camp.list.income$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.income$se.treat[[2]],digits=3))), ")")

tab.a15[1,2]<-paste0(format(unlist(round(org.list.lo$par.treat[[1]],digits=3))), " (", format(unlist(round(org.list.lo$se.treat[[1]],digits=3))), ")")

tab.a15[2,2]<-paste0(format(unlist(round(org.list.hi$par.treat[[1]],digits=3))), " (", format(unlist(round(org.list.hi$se.treat[[1]],digits=3))), ")")

tab.a15[3,2]<-paste0(format(unlist(round(org.list.income$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.income$se.treat[[2]],digits=3))), ")")


tab.a15


########## Table 6

### Campaign Treatment

camp.list.lo.ben <- ictreg(list.resp ~ ben.dum, data = lo.inc.Camp,
                           treat = "list.treat", J=3, method = "lm")

camp.list.lo.pros <- ictreg(list.resp ~ ben.prospera, data = lo.inc.Camp,
                            treat = "list.treat", J=3, method = "lm")

camp.list.lo.non <- ictreg(list.resp ~ ben.non.prospera, data = lo.inc.Camp,
                           treat = "list.treat", J=3, method = "lm")

camp.list.hi.ben <- ictreg(list.resp ~ ben.dum, data = hi.inc.Camp,
                           treat = "list.treat", J=3, method = "lm")

camp.list.hi.pros <- ictreg(list.resp ~ ben.prospera, data = hi.inc.Camp,
                            treat = "list.treat", J=3, method = "lm")

camp.list.hi.non <- ictreg(list.resp ~ ben.non.prospera, data = hi.inc.Camp,
                           treat = "list.treat", J=3, method = "lm")

### Org Treatment

org.list.lo.ben <- ictreg(list.resp ~ ben.dum, data = lo.inc.Org,
                          treat = "list.treat", J=3, method = "lm")

org.list.lo.pros <- ictreg(list.resp ~ ben.prospera, data = lo.inc.Org,
                           treat = "list.treat", J=3, method = "lm")

org.list.lo.non <- ictreg(list.resp ~ ben.non.prospera, data = lo.inc.Org,
                          treat = "list.treat", J=3, method = "lm")

org.list.hi.ben <- ictreg(list.resp ~ ben.dum, data = hi.inc.Org,
                          treat = "list.treat", J=3, method = "lm")

org.list.hi.pros <- ictreg(list.resp ~ ben.prospera, data = hi.inc.Org,
                           treat = "list.treat", J=3, method = "lm")

org.list.hi.non <- ictreg(list.resp ~ ben.non.prospera, data = hi.inc.Org,
                          treat = "list.treat", J=3, method = "lm")

tab.a16<-matrix(NA,6,2)

rownames(tab.a16)<-c("All Beneficiaries","Prospera Beneficiaries", "Non-Prospera Beneficiaries", "All Beneficiaries","Prospera Beneficiaries", "Non-Prospera Beneficiaries")

colnames(tab.a16)<-c("Campaign Treatment", "Org. Treatment")

tab.a16[1,1]<-paste0(format(unlist(round(camp.list.lo.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.lo.ben$se.treat[[2]],digits=3))), ")")

tab.a16[2,1]<-paste0(format(unlist(round(camp.list.lo.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.lo.pros$se.treat[[2]],digits=3))), ")")

tab.a16[3,1]<-paste0(format(unlist(round(camp.list.lo.non$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.lo.non$se.treat[[2]],digits=3))), ")")


tab.a16[4,1]<-paste0(format(unlist(round(camp.list.hi.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.hi.ben$se.treat[[2]],digits=3))), ")")

tab.a16[5,1]<-paste0(format(unlist(round(camp.list.hi.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.hi.pros$se.treat[[2]],digits=3))), ")")

tab.a16[6,1]<-paste0(format(unlist(round(camp.list.hi.non$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.hi.non$se.treat[[2]],digits=3))), ")")

tab.a16[1,2]<-paste0(format(unlist(round(org.list.lo.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.lo.ben$se.treat[[2]],digits=3))), ")")

tab.a16[2,2]<-paste0(format(unlist(round(org.list.lo.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.lo.pros$se.treat[[2]],digits=3))), ")")

tab.a16[3,2]<-paste0(format(unlist(round(org.list.lo.non$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.lo.non$se.treat[[2]],digits=3))), ")")


tab.a16[4,2]<-paste0(format(unlist(round(org.list.hi.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.hi.ben$se.treat[[2]],digits=3))), ")")

tab.a16[5,2]<-paste0(format(unlist(round(org.list.hi.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.hi.pros$se.treat[[2]],digits=3))), ")")

tab.a16[6,2]<-paste0(format(unlist(round(org.list.hi.non$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.hi.non$se.treat[[2]],digits=3))), ")")

tab.a16


########3. Poverty (Occupancy rate): High occupancy = low income

# For high and low income
lo.inc.Camp<-data.listCamp[data.listCamp$occ.rate2=="hi",]
dim(lo.inc.Camp)

hi.inc.Camp<-data.listCamp[data.listCamp$occ.rate2=="lo",]
dim(hi.inc.Camp)

lo.inc.Org<-data.listOrg[data.listOrg$occ.rate2=="hi",]
dim(lo.inc.Org)

hi.inc.Org<-data.listOrg[data.listOrg$occ.rate2=="lo",]
dim(hi.inc.Org)

##### Table 5

### Campaign Treatment

camp.list.lo <- ictreg(list.resp ~ 1, data = lo.inc.Camp,
                       treat = "list.treat", J=3, method = "lm")

camp.list.hi <- ictreg(list.resp ~ 1, data = hi.inc.Camp,
                       treat = "list.treat", J=3, method = "lm")

camp.list.income <- ictreg(list.resp ~ occ.rate2, data = data.listCamp,
                           treat = "list.treat", J=3, method = "lm")

### Org Treatment

org.list.lo <- ictreg(list.resp ~ 1, data = lo.inc.Org,
                      treat = "list.treat", J=3, method = "lm")

org.list.hi <- ictreg(list.resp ~ 1, data = hi.inc.Org,
                      treat = "list.treat", J=3, method = "lm")

org.list.income <- ictreg(list.resp ~ occ.rate2, data = data.listOrg,
                          treat = "list.treat", J=3, method = "lm")

tab.a17<-matrix(NA,3,2)

rownames(tab.a17)<-c("Low Income","High Income", "Difference btwn. Low and High")

colnames(tab.a17)<-c("Campaign Treatment", "Org. Treatment")

tab.a17[1,1]<-paste0(format(unlist(round(camp.list.lo$par.treat[[1]],digits=3))), " (", format(unlist(round(camp.list.lo$se.treat[[1]],digits=3))), ")")

tab.a17[2,1]<-paste0(format(unlist(round(camp.list.hi$par.treat[[1]],digits=3))), " (", format(unlist(round(camp.list.hi$se.treat[[1]],digits=3))), ")")

tab.a17[3,1]<-paste0(format(unlist(round(camp.list.income$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.income$se.treat[[2]],digits=3))), ")")

tab.a17[1,2]<-paste0(format(unlist(round(org.list.lo$par.treat[[1]],digits=3))), " (", format(unlist(round(org.list.lo$se.treat[[1]],digits=3))), ")")

tab.a17[2,2]<-paste0(format(unlist(round(org.list.hi$par.treat[[1]],digits=3))), " (", format(unlist(round(org.list.hi$se.treat[[1]],digits=3))), ")")

tab.a17[3,2]<-paste0(format(unlist(round(org.list.income$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.income$se.treat[[2]],digits=3))), ")")


tab.a17


########## Table 6

### Campaign Treatment

camp.list.lo.ben <- ictreg(list.resp ~ ben.dum, data = lo.inc.Camp,
                           treat = "list.treat", J=3, method = "lm")

camp.list.lo.pros <- ictreg(list.resp ~ ben.prospera, data = lo.inc.Camp,
                            treat = "list.treat", J=3, method = "lm")

camp.list.lo.non <- ictreg(list.resp ~ ben.non.prospera, data = lo.inc.Camp,
                           treat = "list.treat", J=3, method = "lm")

camp.list.hi.ben <- ictreg(list.resp ~ ben.dum, data = hi.inc.Camp,
                           treat = "list.treat", J=3, method = "lm")

camp.list.hi.pros <- ictreg(list.resp ~ ben.prospera, data = hi.inc.Camp,
                            treat = "list.treat", J=3, method = "lm")

camp.list.hi.non <- ictreg(list.resp ~ ben.non.prospera, data = hi.inc.Camp,
                           treat = "list.treat", J=3, method = "lm")

### Org Treatment

org.list.lo.ben <- ictreg(list.resp ~ ben.dum, data = lo.inc.Org,
                          treat = "list.treat", J=3, method = "lm")

org.list.lo.pros <- ictreg(list.resp ~ ben.prospera, data = lo.inc.Org,
                           treat = "list.treat", J=3, method = "lm")

org.list.lo.non <- ictreg(list.resp ~ ben.non.prospera, data = lo.inc.Org,
                          treat = "list.treat", J=3, method = "lm")

org.list.hi.ben <- ictreg(list.resp ~ ben.dum, data = hi.inc.Org,
                          treat = "list.treat", J=3, method = "lm")

org.list.hi.pros <- ictreg(list.resp ~ ben.prospera, data = hi.inc.Org,
                           treat = "list.treat", J=3, method = "lm")

org.list.hi.non <- ictreg(list.resp ~ ben.non.prospera, data = hi.inc.Org,
                          treat = "list.treat", J=3, method = "lm")

tab.a18<-matrix(NA,6,2)

rownames(tab.a18)<-c("All Beneficiaries","Prospera Beneficiaries", "Non-Prospera Beneficiaries", "All Beneficiaries","Prospera Beneficiaries", "Non-Prospera Beneficiaries")

colnames(tab.a18)<-c("Campaign Treatment", "Org. Treatment")

tab.a18[1,1]<-paste0(format(unlist(round(camp.list.lo.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.lo.ben$se.treat[[2]],digits=3))), ")")

tab.a18[2,1]<-paste0(format(unlist(round(camp.list.lo.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.lo.pros$se.treat[[2]],digits=3))), ")")

tab.a18[3,1]<-paste0(format(unlist(round(camp.list.lo.non$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.lo.non$se.treat[[2]],digits=3))), ")")


tab.a18[4,1]<-paste0(format(unlist(round(camp.list.hi.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.hi.ben$se.treat[[2]],digits=3))), ")")

tab.a18[5,1]<-paste0(format(unlist(round(camp.list.hi.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.hi.pros$se.treat[[2]],digits=3))), ")")

tab.a18[6,1]<-paste0(format(unlist(round(camp.list.hi.non$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.hi.non$se.treat[[2]],digits=3))), ")")

tab.a18[1,2]<-paste0(format(unlist(round(org.list.lo.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.lo.ben$se.treat[[2]],digits=3))), ")")

tab.a18[2,2]<-paste0(format(unlist(round(org.list.lo.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.lo.pros$se.treat[[2]],digits=3))), ")")

tab.a18[3,2]<-paste0(format(unlist(round(org.list.lo.non$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.lo.non$se.treat[[2]],digits=3))), ")")


tab.a18[4,2]<-paste0(format(unlist(round(org.list.hi.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.hi.ben$se.treat[[2]],digits=3))), ")")

tab.a18[5,2]<-paste0(format(unlist(round(org.list.hi.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.hi.pros$se.treat[[2]],digits=3))), ")")

tab.a18[6,2]<-paste0(format(unlist(round(org.list.hi.non$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.hi.non$se.treat[[2]],digits=3))), ")")

tab.a18

########4. Rural vs. Urban (Rural  = low income)

# For high and low income
lo.inc.Camp<-data.listCamp[data.listCamp$rural50K==1,]
dim(lo.inc.Camp)

hi.inc.Camp<-data.listCamp[data.listCamp$rural50K==0,]
dim(hi.inc.Camp)

lo.inc.Org<-data.listOrg[data.listCamp$rural50K==1,]
dim(lo.inc.Org)

hi.inc.Org<-data.listOrg[data.listCamp$rural50K==0,]
dim(hi.inc.Org)

##### Table 5

### Campaign Treatment

camp.list.lo <- ictreg(list.resp ~ 1, data = lo.inc.Camp,
                       treat = "list.treat", J=3, method = "lm")

camp.list.hi <- ictreg(list.resp ~ 1, data = hi.inc.Camp,
                       treat = "list.treat", J=3, method = "lm")

camp.list.income <- ictreg(list.resp ~ rural50K, data = data.listCamp,
                           treat = "list.treat", J=3, method = "lm")

### Org Treatment

org.list.lo <- ictreg(list.resp ~ 1, data = lo.inc.Org,
                      treat = "list.treat", J=3, method = "lm")

org.list.hi <- ictreg(list.resp ~ 1, data = hi.inc.Org,
                      treat = "list.treat", J=3, method = "lm")

org.list.income <- ictreg(list.resp ~ rural50K, data = data.listOrg,
                          treat = "list.treat", J=3, method = "lm")

tab.a19<-matrix(NA,3,2)

rownames(tab.a19)<-c("Low Income","High Income", "Difference btwn. Low and High")

colnames(tab.a19)<-c("Campaign Treatment", "Org. Treatment")

tab.a19[1,1]<-paste0(format(unlist(round(camp.list.lo$par.treat[[1]],digits=3))), " (", format(unlist(round(camp.list.lo$se.treat[[1]],digits=3))), ")")

tab.a19[2,1]<-paste0(format(unlist(round(camp.list.hi$par.treat[[1]],digits=3))), " (", format(unlist(round(camp.list.hi$se.treat[[1]],digits=3))), ")")

tab.a19[3,1]<-paste0(format(unlist(round(camp.list.income$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.income$se.treat[[2]],digits=3))), ")")

tab.a19[1,2]<-paste0(format(unlist(round(org.list.lo$par.treat[[1]],digits=3))), " (", format(unlist(round(org.list.lo$se.treat[[1]],digits=3))), ")")

tab.a19[2,2]<-paste0(format(unlist(round(org.list.hi$par.treat[[1]],digits=3))), " (", format(unlist(round(org.list.hi$se.treat[[1]],digits=3))), ")")

tab.a19[3,2]<-paste0(format(unlist(round(org.list.income$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.income$se.treat[[2]],digits=3))), ")")


tab.a19


########## Table 6

### Campaign Treatment

camp.list.lo.ben <- ictreg(list.resp ~ ben.dum, data = lo.inc.Camp,
                           treat = "list.treat", J=3, method = "lm")

camp.list.lo.pros <- ictreg(list.resp ~ ben.prospera, data = lo.inc.Camp,
                            treat = "list.treat", J=3, method = "lm")

camp.list.lo.non <- ictreg(list.resp ~ ben.non.prospera, data = lo.inc.Camp,
                           treat = "list.treat", J=3, method = "lm")

camp.list.hi.ben <- ictreg(list.resp ~ ben.dum, data = hi.inc.Camp,
                           treat = "list.treat", J=3, method = "lm")

camp.list.hi.pros <- ictreg(list.resp ~ ben.prospera, data = hi.inc.Camp,
                            treat = "list.treat", J=3, method = "lm")

camp.list.hi.non <- ictreg(list.resp ~ ben.non.prospera, data = hi.inc.Camp,
                           treat = "list.treat", J=3, method = "lm")

### Org Treatment

org.list.lo.ben <- ictreg(list.resp ~ ben.dum, data = lo.inc.Org,
                          treat = "list.treat", J=3, method = "lm")

org.list.lo.pros <- ictreg(list.resp ~ ben.prospera, data = lo.inc.Org,
                           treat = "list.treat", J=3, method = "lm")

org.list.lo.non <- ictreg(list.resp ~ ben.non.prospera, data = lo.inc.Org,
                          treat = "list.treat", J=3, method = "lm")

org.list.hi.ben <- ictreg(list.resp ~ ben.dum, data = hi.inc.Org,
                          treat = "list.treat", J=3, method = "lm")

org.list.hi.pros <- ictreg(list.resp ~ ben.prospera, data = hi.inc.Org,
                           treat = "list.treat", J=3, method = "lm")

org.list.hi.non <- ictreg(list.resp ~ ben.non.prospera, data = hi.inc.Org,
                          treat = "list.treat", J=3, method = "lm")

tab.a20<-matrix(NA,6,2)

rownames(tab.a20)<-c("All Beneficiaries","Prospera Beneficiaries", "Non-Prospera Beneficiaries", "All Beneficiaries","Prospera Beneficiaries", "Non-Prospera Beneficiaries")

colnames(tab.a20)<-c("Campaign Treatment", "Org. Treatment")

tab.a20[1,1]<-paste0(format(unlist(round(camp.list.lo.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.lo.ben$se.treat[[2]],digits=3))), ")")

tab.a20[2,1]<-paste0(format(unlist(round(camp.list.lo.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.lo.pros$se.treat[[2]],digits=3))), ")")

tab.a20[3,1]<-paste0(format(unlist(round(camp.list.lo.non$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.lo.non$se.treat[[2]],digits=3))), ")")


tab.a20[4,1]<-paste0(format(unlist(round(camp.list.hi.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.hi.ben$se.treat[[2]],digits=3))), ")")

tab.a20[5,1]<-paste0(format(unlist(round(camp.list.hi.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.hi.pros$se.treat[[2]],digits=3))), ")")

tab.a20[6,1]<-paste0(format(unlist(round(camp.list.hi.non$par.treat[[2]],digits=3))), " (", format(unlist(round(camp.list.hi.non$se.treat[[2]],digits=3))), ")")

tab.a20[1,2]<-paste0(format(unlist(round(org.list.lo.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.lo.ben$se.treat[[2]],digits=3))), ")")

tab.a20[2,2]<-paste0(format(unlist(round(org.list.lo.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.lo.pros$se.treat[[2]],digits=3))), ")")

tab.a20[3,2]<-paste0(format(unlist(round(org.list.lo.non$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.lo.non$se.treat[[2]],digits=3))), ")")


tab.a20[4,2]<-paste0(format(unlist(round(org.list.hi.ben$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.hi.ben$se.treat[[2]],digits=3))), ")")

tab.a20[5,2]<-paste0(format(unlist(round(org.list.hi.pros$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.hi.pros$se.treat[[2]],digits=3))), ")")

tab.a20[6,2]<-paste0(format(unlist(round(org.list.hi.non$par.treat[[2]],digits=3))), " (", format(unlist(round(org.list.hi.non$se.treat[[2]],digits=3))), ")")

tab.a20
